Module audio

Module audio 

Host audio output backends.

Provides a trait for audio output and implementations for native (cpal) and null (headless/test) backends.

Structs

CpalAudioBackend
cpal-based audio backend for native GUI mode.
NullAudioBackend
No-op backend for tests, headless mode, and scripted harnesses.

Traits

AudioBackend
Trait for pushing mixed PCM samples to the host audio device.