Module binhex

Module binhex 

BinHex 4.0 decoding for classic Mac single-file containers.

BinHex wraps a Macintosh filename, Finder metadata, data fork, and resource fork in a colon-delimited ASCII stream. Systemless uses the decoded forks as another input to the existing StuffIt, MacBinary, disk-image, and APPL loaders.

Structs

BinHexFile

Functions

decode
looks_like_binhex