Host audio output backends.
Provides a trait for audio output and implementations for native (cpal) and null (headless/test) backends.
Structs
- Cpal
Audio Backend - cpal-based audio backend for native GUI mode.
- Null
Audio Backend - No-op backend for tests, headless mode, and scripted harnesses.
Traits
- Audio
Backend - Trait for pushing mixed PCM samples to the host audio device.