Sound Manager state and mixing engine.
Holds per-channel playback state and produces mixed PCM output each frame. Reference: Inside Macintosh: Sound (1994).
Modules
- cmd
- Sound command constants (Sound 1994, 2-92 to 2-97).
Structs
- Double
Buffer State - Double-buffer playback state for SndPlayDoubleBuffer. Sound 1994, 2-111 to 2-113
- Pending
Double Back Callback - A pending double-buffer callback that the runner should fire.
- SndChannel
- Per-channel state.
- SndCommand
- A sound command extracted from a snd resource or queued via SndDoCommand. Sound 1994, 2-92
- Sound
Manager - Top-level sound manager state, owned by TrapDispatcher.
Enums
- Pending
Sound Callback - A pending callback or completion routine to fire from interrupt context.
Constants
- OUTPUT_
RATE - Output sample rate in Hz.
- RATE_
11KHZ_ FIXED - Classic Sound Manager
rate11khzfixed-point value (11127.27273 Hz). - RATE_
22KHZ_ FIXED - Classic Sound Manager
rate22khzfixed-point value (22254.54545 Hz).